/**
 * Copyright (c) 2002-2013 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.server.rest.transactional;

import org.neo4j.kernel.GraphDatabaseAPI;
import org.neo4j.kernel.api.KernelAPI;
import org.neo4j.kernel.api.StatementContext;
import org.neo4j.kernel.api.TransactionContext;
import org.neo4j.kernel.impl.transaction.TxManager;

public class TransitionalPeriodTransactionMessContainer implements KernelAPI
{

    private final KernelAPI kernel;
    private final GraphDatabaseAPI db;
    private final TxManager txManager;

    public TransitionalPeriodTransactionMessContainer( GraphDatabaseAPI db )
    {
        this.db = db;
        this.kernel = db.getDependencyResolver().resolveDependency( KernelAPI.class );
        this.txManager = db.getDependencyResolver().resolveDependency( TxManager.class );
    }

    public TransactionContext newTransactionContext()
    {
        db.beginTx();
        return new TransitionalTxManagementTransactionContext( kernel.newTransactionContext(), txManager );
    }

    @Override
    public StatementContext newReadOnlyStatementContext()
    {
        throw new UnsupportedOperationException();
    }
}
